@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- * Copyright © 2016 James Hunt <jamesodhunt@ubuntu.com>.
+ * Copyright © 2016 James Hunt <jamesodhunt@gmail.com>.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ static struct procenv_map scheduler_map[] = {
 	mk_map_entry (SCHED_IDLE),
 #endif
 
-	{ 0, NULL }
+	{ NULL, 0 }
 };
 
 static struct procenv_map signal_map_linux[] = {
@@ -38,7 +38,7 @@ static struct procenv_map signal_map_linux[] = {
 	mk_map_entry (SIGALRM),
 	mk_map_entry (SIGBUS),
 
-	{ SIGCHLD, "SIGCHLD|SIGCLD" },
+	{"SIGCHLD|SIGCLD", SIGCHLD},
 
 	mk_map_entry (SIGCONT),
 	mk_map_entry (SIGFPE),
@@ -60,7 +60,7 @@ static struct procenv_map signal_map_linux[] = {
 	mk_map_entry (SIGIO),
 	mk_map_entry (SIGIOT),
 
-	{SIGPOLL, "SIGPOLL|SIGIO" },
+	{"SIGPOLL|SIGIO", SIGPOLL},
 
 	mk_map_entry (SIGPROF),
 
@@ -80,7 +80,7 @@ static struct procenv_map signal_map_linux[] = {
 	mk_map_entry (SIGXCPU),
 	mk_map_entry (SIGXFSZ),
 
-	{ 0, NULL },
+	{ NULL, 0 },
 };
 
 static struct procenv_map if_flag_map_linux[] = {
@@ -106,7 +106,7 @@ static struct procenv_map if_flag_map_linux[] = {
 	mk_map_entry (IFF_ECHO),
 #endif
 
-	{ 0, NULL }
+	{ NULL, 0 }
 };
 
 static struct procenv_map if_extended_flag_map_linux[] = {
@@ -134,7 +134,7 @@ static struct procenv_map if_extended_flag_map_linux[] = {
 #if defined (IFF_ISATAP)
 	mk_map_entry (IFF_ISATAP),
 #endif
-	{ 0, NULL }
+	{ NULL, 0 }
 };
 
 static struct procenv_map personality_map_linux[] = {
@@ -164,7 +164,7 @@ static struct procenv_map personality_map_linux[] = {
 	mk_map_entry (PER_OSF4),
 	mk_map_entry (PER_HPUX),
 
-	{ 0, NULL }
+	{ NULL, 0 }
 };
 
 static struct procenv_map personality_flag_map_linux[] = {
@@ -196,7 +196,7 @@ static struct procenv_map personality_flag_map_linux[] = {
 	mk_map_entry (WHOLE_SECONDS),
 #endif
 
-	{ 0, NULL }
+	{ NULL, 0 }
 };
 
 /* lifted from include/linux/ioprio.h since not available in libc */
@@ -226,7 +226,7 @@ static struct procenv_map io_priorities_class_map[] = {
 	mk_map_entry (IOPRIO_CLASS_IDLE),
 	mk_map_entry (IOPRIO_CLASS_NORMAL),
 
-	{ 0, NULL }
+	{ NULL, 0 }
 };
 
 static char *
@@ -239,7 +239,7 @@ pid_to_name (pid_t pid)
 	sprintf (path, "/proc/%d/cmdline", (int)pid);
 
 	f = fopen (path, "r");
-	if (! f) 
+	if (! f)
 		goto out;
 
 	/* Reuse buffer */
@@ -355,6 +355,24 @@ show_capabilities_linux (void)
 	}
 #endif /* CAP_AUDIT_READ */
 
+#ifdef CAP_PERFMON
+	if (LINUX_KERNEL_MM (5, 8)) {
+		show_capability (caps, CAP_PERFMON);
+	}
+#endif /* CAP_PERFMON */
+
+#ifdef CAP_BPF
+	if (LINUX_KERNEL_MM (5, 8)) {
+		show_capability (caps, CAP_BPF);
+	}
+#endif /* CAP_BPF */
+
+#ifdef CAP_CHECKPOINT_RESTORE
+	if (LINUX_KERNEL_MM (5, 9)) {
+		show_capability (caps, CAP_CHECKPOINT_RESTORE);
+	}
+#endif /* CAP_CHECKPOINT_RESTORE */
+
 	section_close ();
 
 	/* It's possible that procenv is running on a system which has
@@ -444,7 +462,7 @@ show_cgroups_linux (void)
 	const  char  *delim = ":";
 	char         *file = "/proc/self/cgroup";
 	FILE         *f;
-	char          buffer[1024];
+	char          buffer[PROCENV_BUFFER];
 	size_t        len;
 
 	f = fopen (file, "r");
@@ -698,7 +716,7 @@ procenv_getcpu (void)
 	FILE        *f;
 	char       **fields;
 	const char  *field;
-	char         buffer[1024];
+	char         buffer[PROCENV_BUFFER];
 	size_t       len;
 	size_t       count;
 
@@ -724,7 +742,7 @@ procenv_getcpu (void)
 
 	field = fields[41];
 	assert (field);
-	
+
 	cpu = atoi (field);
 
 cleanup:
@@ -922,10 +940,10 @@ show_prctl_linux (void)
 		else {
 			switch (arg2) {
 			case PR_ENDIAN_BIG:
-				value = BIG_STR; 
+				value = BIG_STR;
 				break;
 			case PR_ENDIAN_LITTLE:
-				value = LITTLE_STR; 
+				value = LITTLE_STR;
 				break;
 			case PR_ENDIAN_PPC_LITTLE:
 				value = "PowerPC pseudo little endian";
@@ -1235,7 +1253,7 @@ show_prctl_linux (void)
 static void
 handle_proc_branch_linux (void)
 {
-	char    buffer[1024];
+	char    buffer[PROCENV_BUFFER];
 	char    path[PATH_MAX];
 	char    name[16];
 	char    pid[16];
@@ -1263,12 +1281,12 @@ handle_proc_branch_linux (void)
 
 			if ((p=strstr (buffer, "Name:")) == buffer) {
 				p += 1+strlen ("Name:"); /* jump over tab char */
-				sprintf (name, "%s", p);
+				sprintf (name, "%.*s", PROCENV_TASK_COMM_NAME_LEN, p);
 			}
 
 			if ((p=strstr (buffer, "PPid:")) == buffer) {
 				p += 1+strlen ("PPid:"); /* jump over tab char */
-				sprintf (ppid, "%s", p);
+				sprintf (ppid, "%.*s", PROCENV_TASK_COMM_NAME_LEN, p);
 
 				/* got all we need now */
 				break;
@@ -1907,7 +1925,7 @@ linux_kernel_version (int major, int minor, int revision)
 	/* We need something to compare against */
 	assert (ret && actual_major != -1);
 
-	requested_version |= (0xFF0000 & (major << 16)); 
+	requested_version |= (0xFF0000 & (major << 16));
 
 	if (minor != -1) {
 		requested_version |= (0x00FF00 & (minor << 8));
@@ -1924,7 +1942,7 @@ linux_kernel_version (int major, int minor, int revision)
 		actual_version |= (0x00FF00 & (actual_minor << 8));
 
 	if (actual_major != -1)
-		actual_version |= (0xFF0000 & (actual_major << 16)); 
+		actual_version |= (0xFF0000 & (actual_major << 16));
 
 
 	if (actual_version >= requested_version)
@@ -1946,6 +1964,17 @@ get_capability_by_flag_type (cap_t cap_p, cap_flag_t type, cap_value_t cap)
 
     return ret < 0 ? ret : result;
 }
+
+static int
+get_ambient_capability (cap_value_t cap)
+{
+	if (!LINUX_KERNEL_MMR (4, 3, 0)) {
+		return false;
+	}
+
+	return prctl (PR_CAP_AMBIENT, PR_CAP_AMBIENT_IS_SET, cap) == 1;
+}
+
 #endif /* HAVE_SYS_CAPABILITY_H */
 
 #if defined (HAVE_SYS_CAPABILITY_H)
@@ -2135,7 +2164,7 @@ in_vm_linux (void)
 	bool result = false;
 	const char *cpuinfo = "/proc/cpuinfo";
 	FILE *f = NULL;
-	char buffer[1024];
+	char buffer[PROCENV_BUFFER];
 
 	f = fopen (cpuinfo, "r");
 	if (! f) {
@@ -2205,8 +2234,8 @@ struct procenv_ops platform_ops =
 	.show_shared_mem               = show_shared_mem_linux,
 	.show_timezone                 = show_timezone_linux,
 
+	.handle_memory                 = show_memory_generic,
 	.handle_numa_memory            = handle_numa_memory_linux,
 	.handle_proc_branch            = handle_proc_branch_linux,
 	.handle_scheduler_type         = handle_scheduler_type_linux,
-
 };
