@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- * Copyright © 2016 James Hunt <jamesodhunt@ubuntu.com>.
+ * Copyright © 2016 James Hunt <jamesodhunt@gmail.com>.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -68,9 +68,6 @@ show_clocks_generic (void)
 
 #if defined (PROCENV_PLATFORM_LINUX) || defined (PROCENV_PLATFORM_HURD)
 
-#ifdef CLOCK_MONOTONIC_RAW
-	show_clock_res (CLOCK_MONOTONIC_RAW);
-#endif
 	show_clock_res (CLOCK_PROCESS_CPUTIME_ID);
 	show_clock_res (CLOCK_THREAD_CPUTIME_ID);
 #if defined CLOCK_BOOTTIME
@@ -78,6 +75,11 @@ show_clocks_generic (void)
 #endif
 
 #endif
+
+#if defined CLOCK_TAI
+	show_clock_res (CLOCK_TAI);
+#endif
+
 }
 
 #endif
@@ -456,7 +458,7 @@ show_confstrs_generic (void)
 
 /* Display cpu affinities in the same compressed but reasonably
  * human-readable fashion as /proc/self/status:Cpus_allowed_list under Linux.
- */ 
+ */
 void
 show_cpu_affinities_generic (void)
 {
@@ -536,6 +538,61 @@ show_cpu_affinities_generic (void)
 	free (cpu_list);
 }
 
+#if defined (PROCENV_PLATFORM_HURD)
+
+/* Although hurd has the "sys/sysinfo.h" header, it doesn't contain a
+ * prototype for sysinfo(2) since the kernel doesn't provide this system call.
+ */
+void show_memory_generic (void) {}
+
+#else /* !PROCENV_PLATFORM_HURD */
+
+void
+show_memory_generic (void)
+{
+	struct sysinfo info;
+
+	int ret = sysinfo (&info);
+
+	if (ret < 0) {
+		return;
+	}
+
+	int multiplier = info.mem_unit;
+
+	unsigned long total_ram  = info.totalram * multiplier;
+	unsigned long free_ram   = info.freeram * multiplier;
+	unsigned long shared_ram = info.sharedram * multiplier;
+	unsigned long buffer_ram = info.bufferram * multiplier;
+
+	unsigned long total_swap = info.totalswap * multiplier;
+	unsigned long free_swap  = info.freeswap * multiplier;
+
+	/*------------------------------*/
+
+	section_open ("ram");
+
+	mk_mem_section ("total", total_ram);
+	mk_mem_section ("free", free_ram);
+	mk_mem_section ("shared", shared_ram);
+	mk_mem_section ("buffer", buffer_ram);
+
+	section_close ();
+
+	/*------------------------------*/
+
+	section_open ("swap");
+
+	mk_mem_section ("total", total_swap);
+	mk_mem_section ("free", free_swap);
+
+	section_close ();
+
+	/*------------------------------*/
+}
+
+#endif /* PROCENV_PLATFORM_HURD */
+
 #endif /* PROCENV_PLATFORM_LINUX || PROCENV_PLATFORM_FREEBSD || PROCENV_PLATFORM_HURD */
 
 #if defined (PROCENV_PLATFORM_LINUX) || \
@@ -645,6 +702,39 @@ show_pathconfs (ShowMountType what,
 
 #endif
 
+#if !defined (PROCENV_PLATFORM_HURD)
+
+#define PROCENV_KB (1024)
+#define PROCENV_MB (1024*PROCENV_KB)
+#define PROCENV_GB (1024*PROCENV_MB)
+
+void
+show_human_size_entry (size_t value)
+{
+	double result;
+	char *units;
+
+	if (value > PROCENV_GB) {
+		result = ((double)value/PROCENV_GB);
+		units = "GB";
+	} else if (value > PROCENV_MB) {
+		result = ((double)value/PROCENV_MB);
+		units = "MB";
+	} else if (value > PROCENV_KB) {
+		result = ((double)value/PROCENV_KB);
+		units = "KB";
+	} else {
+		result = (double)value;
+		units = "bytes";
+	}
+
+	entry ("human", "%2.2f %s",
+			result,
+			units);
+}
+
+#endif /* !PROCENV_PLATFORM_HURD */
+
 #if defined (PROCENV_PLATFORM_BSD)   || \
     defined (PROCENV_PLATFORM_MINIX) || \
     defined (PROCENV_PLATFORM_DARWIN)
@@ -758,7 +848,7 @@ show_mounts_generic_bsd (ShowMountType what,
 			entry ("minor", "%u", minor);
 			section_close ();
 
-			entry ("fsid", "%.*x%.*x", 
+			entry ("fsid", "%.*x%.*x",
 					2 * sizeof (PROCENV_MNT_GET_FSID (mnt)[0]),
 					PROCENV_MNT_GET_FSID (mnt)[0],
 					2 * sizeof (PROCENV_MNT_GET_FSID (mnt)[1]),
@@ -913,7 +1003,7 @@ show_mounts_generic_linux (ShowMountType what)
 
 				fsid_val.fsid = fs.f_fsid;
 
-				entry ("fsid", "%.*x%.*x", 
+				entry ("fsid", "%.*x%.*x",
 						2 * sizeof (fsid_val.val[0]),
 						fsid_val.val[0],
 						2 * sizeof (fsid_val.val[1]),
