@@ -4,12 +4,12 @@
  *
  * Date: 24 October 2012.
  *
- * Author: James Hunt <jamesodhunt@ubuntu.com>.
+ * Author: James Hunt <jamesodhunt@gmail.com>.
  *
  * Licence: GPLv3. See below...
  *--------------------------------------------------------------------
  *
- * Copyright © 2012-2016 James Hunt <jamesodhunt@ubuntu.com>.
+ * Copyright © 2012-2016 James Hunt <jamesodhunt@gmail.com>.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  *--------------------------------------------------------------------
  */
 
-#include <procenv.h>
+#include "procenv.h"
 
 /**
  * doc:
@@ -154,7 +154,7 @@ struct procenv_map sysconf_map[] = {
 #endif
 
 #if defined (_SC_2_UPE)
-	mk_sysconf_map_entry (_SC_2_UPE), 
+	mk_sysconf_map_entry (_SC_2_UPE),
 #endif
 
 #if defined (_SC_2_VERSION)
@@ -945,7 +945,7 @@ struct procenv_map sysconf_map[] = {
 	mk_sysconf_map_entry (_SC_XOPEN_XCU_VERSION),
 #endif
 
-	{ 0, NULL }
+	{ NULL , 0 }
 };
 
 struct procenv_map locale_map[] = {
@@ -976,7 +976,7 @@ struct procenv_map locale_map[] = {
 #endif
 	mk_map_entry (LC_TIME),
 
-	{ 0, NULL }
+	{ NULL , 0 }
 };
 
 struct procenv_map thread_sched_policy_map[] = {
@@ -1088,7 +1088,6 @@ usage (void)
 	show ("    the data in a flattened format with each value on a separate line");
 	show ("    preceded by all appropriate headings which are separated by the");
 	show ("    current separator.");
-	show ("");
 }
 
 /**
@@ -1440,6 +1439,9 @@ show_memory (void)
 
 	entry ("page size", "%d bytes", getpagesize ());
 
+	if (ops->handle_memory)
+		ops->handle_memory ();
+
 	if (ops->handle_numa_memory)
 		ops->handle_numa_memory ();
 
@@ -1897,7 +1899,7 @@ show_stat (void)
 	modestr = format_perms (st.st_mode);
 	if (! modestr)
 		die ("failed to allocate space for permissions string");
-	perms = (st.st_mode &= ~S_IFMT);
+	perms = (st.st_mode & ~S_IFMT);
 
 	if (perms & S_ISUID)
 		modestr[3] = 's';
@@ -2918,7 +2920,7 @@ show_rlimits (void)
 		ops->show_rlimits ();
 
 	footer ();
-} 
+}
 
 void
 show_confstrs (void)
@@ -3733,7 +3735,7 @@ get_path (const char *argv0)
 
 	tmp = path;
 	for (element = strsep (&tmp, ":");
-			element;            
+			element;
 			element = strsep (&tmp, ":")) {
 
 		sprintf (possible, "%s%s%s",
@@ -4380,7 +4382,7 @@ format_perms (mode_t mode)
 	modestr[i++] = (perms & S_IWOTH) ? 'w' : '-';
 	modestr[i++] = (perms & S_IXOTH) ? 'x' : '-';
 
-	perms = (mode &= ~S_IFMT);
+	perms = (mode & ~S_IFMT);
 	if (perms & S_ISUID)
 		modestr[3] = 's';
 	if (perms & S_ISGID)
