@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- * Copyright © 2012-2016 James Hunt <jamesodhunt@ubuntu.com>.
+ * Copyright © 2012-2016 James Hunt <jamesodhunt@gmail.com>.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -78,6 +78,10 @@
 #include <sys/time.h>
 #include <sys/resource.h>
 
+#if !defined (PROCENV_PLATFORM_DARWIN)
+#include <sys/sysinfo.h>
+#endif
+
 #include "util.h"
 #include "string-util.h"
 #include "pr_list.h"
@@ -162,8 +166,14 @@
  *   - Sort feature-test macros.
  * VERSION 17:
  *   - Added 'vm' to --misc output.
+ * VERSION 18:
+ *   - Added 'ambient' to --capabilities output.
+ * VERSION 19:
+ *  - Added more details to --memory and new capabilities to --capabilities.
+ * VERSION 20:
+ *  - More --memory details for Darwin.
  **/
-#define PROCENV_FORMAT_VERSION 17
+#define PROCENV_FORMAT_VERSION 20
 
 #if defined (PROCENV_PLATFORM_LINUX) || defined (PROCENV_PLATFORM_HURD)
 
@@ -195,7 +205,7 @@
 /* Size of blocks we will show the user (as df(1) does) */
 #define DF_BLOCK_SIZE 1024
 
-#define PROGRAM_AUTHORS "James Hunt <jamesodhunt@ubuntu.com>"
+#define PROGRAM_AUTHORS "James O. D. Hunt <jamesodhunt@gmail.com>"
 
 #define type_hex_width(type) \
 	(sizeof (type) * 2)
@@ -255,10 +265,10 @@
 }
 
 #define SPEED(s) \
-	{s, #s }
+	{#s, s}
 
 #define mk_map_entry(s) \
-	{s, #s }
+	{#s, s}
 
 #define show_confstr(s) \
 { \
@@ -329,7 +339,7 @@
  	sysconf (s)
 
 #define mk_sysconf_map_entry(name) \
-	{name, #name }
+	{#name, name }
 
 #define show_sizeof_type(type) \
 	entry (#type, "%lu byte%s", \
